/// ==============================================================================================
/// Namespace   : ScipBe.FontComboManagerDemo
/// Version     : 1.0
/// Author      : Stefan Cruysberghs
/// Website     : www.scip.be
/// Date        : September 2006 - May 2007
/// Description : Demo application to show features of FontComboBox and FontManager
/// Status      : Open source - Mozilla Public License 1.1
/// ==============================================================================================

using System;
using System.Windows.Forms;
using ScipBe.Controls.WinForms;

namespace ScipBe.Demo.FontComboManager.WinForms
{
  public partial class FormFontComboManager : Form
  {
    public FormFontComboManager()
    {
      InitializeComponent();
    }

    private void Form1_Load(object sender, EventArgs e)
    {
      fontComboBox1.FontManager = fontManager1;
      fontManager1.Populate();

      fontComboBox1.FontItemDrawEngine = new ModernFontItemDrawEngine();
      fontComboBox1.DropDownWidth = 400;
    }

    private void radioButtonSimple_CheckedChanged(object sender, EventArgs e)
    {
      fontComboBox1.FontItemDrawEngine = new SimpleFontItemDrawEngine();
      fontComboBox1.DropDownWidth = 200;
    }

    private void radioButtonModern_CheckedChanged(object sender, EventArgs e)
    {
      fontComboBox1.FontItemDrawEngine = new ModernFontItemDrawEngine();
      fontComboBox1.DropDownWidth = 400;
    }

    private void buttonAddArial_Click(object sender, EventArgs e)
    {
      fontManager1.RecentlyUsedFontItems.Add("Arial");
    }

    private void buttonAddWindings_Click(object sender, EventArgs e)
    {
      fontManager1.RecentlyUsedFontItems.Add("Wingdings");
    }

    private void buttonAddCalibri_Click(object sender, EventArgs e)
    {
      fontManager1.ThemeFontItems.Add("Calibri", "body");
    }

    private void buttonAddVerdana_Click(object sender, EventArgs e)
    {
      fontManager1.ThemeFontItems.Add("Verdana", "header");
    }

    private void buttonRemoveArial_Click(object sender, EventArgs e)
    {
      fontManager1.RecentlyUsedFontItems.Remove("Arial");
    }

    private void buttonRemoveWindings_Click(object sender, EventArgs e)
    {
      fontManager1.RecentlyUsedFontItems.Remove("Wingdings");
    }

    private void buttonRemoveCalibri_Click(object sender, EventArgs e)
    {
      fontManager1.ThemeFontItems.Remove("Calibri");
    }

    private void buttonRemoveVerdana_Click(object sender, EventArgs e)
    {
      fontManager1.ThemeFontItems.Remove("MS Outlook");
    }

    private void checkBoxInstalled_CheckedChanged(object sender, EventArgs e)
    {
      fontComboBox1.OptionsView.ShowInstalledFonts = checkBoxInstalled.Checked;
    }

    private void checkBoxTheme_CheckedChanged(object sender, EventArgs e)
    {
      fontComboBox1.OptionsView.ShowThemeFonts = checkBoxTheme.Checked;
    }

    private void checkBoxRecentlyUsed_CheckedChanged(object sender, EventArgs e)
    {
      fontComboBox1.OptionsView.ShowRecentlyUsedFonts = checkBoxRecentlyUsed.Checked;
    }

      private void checkBoxIrregular_CheckedChanged(object sender, EventArgs e)
      {
        fontComboBox1.OptionsView.ShowIrregularFonts = checkBoxIrregular.Checked;
      }

      private void checkBoxSymbol_CheckedChanged(object sender, EventArgs e)
      {
        fontComboBox1.OptionsView.ShowSymbolFonts = checkBoxSymbol.Checked;
      }

      private void checkBoxAddRecentlyUsed_CheckedChanged(object sender, EventArgs e)
      {
         fontComboBox1.OptionsBehavior.AddSelectedFontToRecentlyUsed = checkBoxAddRecentlyUsed.Checked;
      }
      
      private void fontComboBox1_SelectedIndexChanged(object sender, EventArgs e)
      {
          //
      }

      private void fontComboBox1_SelectedValueChanged(object sender, EventArgs e)
      {
          //
      }

    private void buttonShowFont_Click(object sender, EventArgs e)
    {
      if (fontComboBox1.SelectedItem != null)
        MessageBox.Show(fontComboBox1.SelectedItem.ToString() 
          + ' ' + ((FontItem) fontComboBox1.SelectedItem).TextMetrics.PanoseFamilyType.ToString());
    }

  }
}